=== modified file '.bzrignore'
--- .bzrignore	2011-11-05 03:32:21 +0000
+++ .bzrignore	2011-11-18 02:03:41 +0000
@@ -379,3 +379,4 @@
 plugin/innobase/xtrabackup/drizzlebackup.innobase
 libdrizzle-2.0/drizzle_password_hash
 libdrizzle-2.0/mysql_password_hash
+tags

=== modified file 'libdrizzle-2.0/column.cc'
--- libdrizzle-2.0/column.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/column.cc	2011-11-18 02:03:41 +0000
@@ -354,28 +354,32 @@
 drizzle_column_st *drizzle_column_create(drizzle_result_st *result,
                                          drizzle_column_st *column)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (column == NULL)
   {
-    column= new drizzle_column_st;
-    column->result = result;
+    column= new (std::nothrow)drizzle_column_st;
+    column->result= result;
     /* SET BELOW: column->next */
-    column->prev = NULL;
+    column->prev= NULL;
     column->options= DRIZZLE_COLUMN_ALLOCATED;
-    column->catalog[0] = '\0';
-    column->db[0] = '\0';
-    column->table[0] = '\0';
-    column->orig_table[0] = '\0';
-    column->name[0] = '\0';
-    column->orig_name[0] = '\0';
-    column->charset = 0;
-    column->size = 0;
-    column->max_size = 0;
-    column->type = static_cast<drizzle_column_type_t>(0);
-    column->flags = drizzle_column_flags_t();
-    column->decimals = 0;
+    column->catalog[0]= '\0';
+    column->schema[0]= '\0';
+    column->table[0]= '\0';
+    column->orig_table[0]= '\0';
+    column->name[0]= '\0';
+    column->orig_name[0]= '\0';
+    column->charset= 0;
+    column->size= 0;
+    column->max_size= 0;
+    column->type= static_cast<drizzle_column_type_t>(0);
+    column->flags= drizzle_column_flags_t();
+    column->decimals= 0;
     /* UNSET: column->default_value */
-    column->default_value_size = 0;
-
+    column->default_value_size= 0;
   }
   else
   {
@@ -384,7 +388,7 @@
     column->prev = NULL;
     column->options= drizzle_column_options_t();
     column->catalog[0] = '\0';
-    column->db[0] = '\0';
+    column->schema[0] = '\0';
     column->table[0] = '\0';
     column->orig_table[0] = '\0';
     column->name[0] = '\0';
@@ -411,90 +415,184 @@
 
 void drizzle_column_free(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (column->result->column_list == column)
+  {
     column->result->column_list= column->next;
+  }
+
   if (column->prev)
+  {
     column->prev->next= column->next;
+  }
+
   if (column->next)
+  {
     column->next->prev= column->prev;
+  }
 
   if (column->options & DRIZZLE_COLUMN_ALLOCATED)
+  {
     delete column;
+  }
 }
 
 drizzle_result_st *drizzle_column_drizzle_result(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->result;
 }
 
 const char *drizzle_column_catalog(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->catalog;
 }
 
+const char *drizzle_column_shema(drizzle_column_st *column)
+{
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
+  return column->schema;
+}
+
 const char *drizzle_column_db(drizzle_column_st *column)
 {
-  return column->db;
+  return drizzle_column_shema(column);
 }
 
 const char *drizzle_column_table(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->table;
 }
 
 const char *drizzle_column_orig_table(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->orig_table;
 }
 
 const char *drizzle_column_name(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->name;
 }
 
 const char *drizzle_column_orig_name(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->orig_name;
 }
 
 drizzle_charset_t drizzle_column_charset(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->charset;
 }
 
 uint32_t drizzle_column_size(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->size;
 }
 
 size_t drizzle_column_max_size(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->max_size;
 }
 
 void drizzle_column_set_max_size(drizzle_column_st *column, size_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->max_size= size;
 }
 
 drizzle_column_type_t drizzle_column_type(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return drizzle_column_type_t();
+  }
+
   return column->type;
 }
 
-drizzle_column_type_drizzle_t
-drizzle_column_type_drizzle(drizzle_column_st *column)
+drizzle_column_type_drizzle_t drizzle_column_type_drizzle(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return drizzle_column_type_drizzle_t();
+  }
+
   return _column_type_drizzle_map_from[column->type];
 }
 
 int drizzle_column_flags(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->flags;
 }
 
 uint8_t drizzle_column_decimals(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->decimals;
 }
 
@@ -511,7 +609,11 @@
 
 drizzle_return_t drizzle_column_skip(drizzle_result_st *result)
 {
-  drizzle_return_t ret;
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->options|= DRIZZLE_RESULT_SKIP_COLUMN;
@@ -519,21 +621,25 @@
     drizzle_state_push(result->con, drizzle_state_column_read);
     drizzle_state_push(result->con, drizzle_state_packet_read);
   }
-  ret= drizzle_state_loop(result->con);
+  drizzle_return_t ret= drizzle_state_loop(result->con);
   result->options&= ~DRIZZLE_RESULT_SKIP_COLUMN;
   return ret;
 }
 
 drizzle_return_t drizzle_column_skip_all(drizzle_result_st *result)
 {
-  drizzle_return_t ret;
-  uint16_t it;
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
 
-  for (it= 1; it <= result->column_count; it++)
+  for (uint16_t it= 1; it <= result->column_count; it++)
   {
-    ret= drizzle_column_skip(result);
+    drizzle_return_t ret= drizzle_column_skip(result);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 
   return DRIZZLE_RETURN_OK;
@@ -543,6 +649,11 @@
                                        drizzle_column_st *column,
                                        drizzle_return_t *ret_ptr)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->column= column;
@@ -557,6 +668,11 @@
 
 drizzle_return_t drizzle_column_buffer(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_return_t ret;
 
   if (result->column_buffer == NULL)
@@ -587,8 +703,15 @@
 
 drizzle_column_st *drizzle_column_next(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (result->column_current == result->column_count)
+  {
     return NULL;
+  }
 
   result->column_current++;
   return &(result->column_buffer[result->column_current - 1]);
@@ -605,21 +728,39 @@
 
 void drizzle_column_seek(drizzle_result_st *result, uint16_t column)
 {
+  if (result == NULL)
+  {
+    return;
+  }
+
   if (column <= result->column_count)
+  {
     result->column_current= column;
+  }
 }
 
-drizzle_column_st *drizzle_column_index(drizzle_result_st *result,
-                                        uint16_t column)
+drizzle_column_st *drizzle_column_index(drizzle_result_st *result, uint16_t column)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (column >= result->column_count)
+  {
     return NULL;
+  }
 
   return &(result->column_buffer[column]);
 }
 
 uint16_t drizzle_column_current(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return 0;
+  }
+
   return result->column_current;
 }
 
@@ -630,6 +771,11 @@
 drizzle_return_t drizzle_column_write(drizzle_result_st *result,
                                       drizzle_column_st *column)
 {
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->column= column;
@@ -642,8 +788,15 @@
 
 void drizzle_column_set_catalog(drizzle_column_st *column, const char *catalog)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (catalog == NULL)
+  {
     column->catalog[0]= 0;
+  }
   else
   {
     strncpy(column->catalog, catalog, DRIZZLE_MAX_CATALOG_SIZE);
@@ -651,21 +804,41 @@
   }
 }
 
-void drizzle_column_set_db(drizzle_column_st *column, const char *db)
+void drizzle_column_set_schema(drizzle_column_st *column, const char *schema)
 {
-  if (db == NULL)
-    column->db[0]= 0;
+  if (column == NULL)
+  {
+    return;
+  }
+
+  if (schema == NULL)
+  {
+    column->schema[0]= 0;
+  }
   else
   {
-    strncpy(column->db, db, DRIZZLE_MAX_DB_SIZE);
-    column->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+    strncpy(column->schema, schema, DRIZZLE_MAX_DB_SIZE);
+    column->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
   }
 }
 
+void drizzle_column_set_db(drizzle_column_st *column, const char *schema)
+{
+  drizzle_column_set_schema(column, schema);
+}
+
+
 void drizzle_column_set_table(drizzle_column_st *column, const char *table)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (table == NULL)
+  {
     column->table[0]= 0;
+  }
   else
   {
     strncpy(column->table, table, DRIZZLE_MAX_TABLE_SIZE);
@@ -676,6 +849,11 @@
 void drizzle_column_set_orig_table(drizzle_column_st *column,
                                    const char *orig_table)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (orig_table == NULL)
     column->orig_table[0]= 0;
   else
@@ -687,6 +865,11 @@
 
 void drizzle_column_set_name(drizzle_column_st *column, const char *name)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (name == NULL)
     column->name[0]= 0;
   else
@@ -699,6 +882,11 @@
 void drizzle_column_set_orig_name(drizzle_column_st *column,
                                   const char *orig_name)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (orig_name == NULL)
     column->orig_name[0]= 0;
   else
@@ -711,28 +899,53 @@
 void drizzle_column_set_charset(drizzle_column_st *column,
                                 drizzle_charset_t charset)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->charset= charset;
 }
 
 void drizzle_column_set_size(drizzle_column_st *column, uint32_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->size= size;
 }
 
 void drizzle_column_set_type(drizzle_column_st *column,
                              drizzle_column_type_t type)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->type= type;
 }
 
 void drizzle_column_set_flags(drizzle_column_st *column,
                               int flags)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->flags= flags;
 }
 
 void drizzle_column_set_decimals(drizzle_column_st *column, uint8_t decimals)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->decimals= decimals;
 }
 
@@ -740,8 +953,15 @@
                                       const uint8_t *default_value,
                                       size_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (default_value == NULL)
+  {
     column->default_value[0]= 0;
+  }
   else
   {
     if (size < DRIZZLE_MAX_DEFAULT_VALUE_SIZE)
@@ -766,6 +986,11 @@
 
 drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_column_st *column;
   drizzle_column_type_drizzle_t drizzle_type;
 
@@ -809,7 +1034,7 @@
     /* These functions can only fail if they need to read data, but we know we
        buffered the entire packet, so ignore returns. */
     (void)drizzle_unpack_string(con, column->catalog, DRIZZLE_MAX_CATALOG_SIZE);
-    (void)drizzle_unpack_string(con, column->db, DRIZZLE_MAX_DB_SIZE);
+    (void)drizzle_unpack_string(con, column->schema, DRIZZLE_MAX_DB_SIZE);
     (void)drizzle_unpack_string(con, column->table, DRIZZLE_MAX_TABLE_SIZE);
     (void)drizzle_unpack_string(con, column->orig_table,
                                 DRIZZLE_MAX_TABLE_SIZE);
@@ -867,6 +1092,11 @@
 
 drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   uint8_t *start= con->buffer_ptr + con->buffer_size;
   uint8_t *ptr;
   drizzle_column_st *column= con->result->column;
@@ -875,7 +1105,7 @@
 
   /* Calculate max packet size. */
   con->packet_size= 9 + strlen(column->catalog)
-                  + 9 + strlen(column->db)
+                  + 9 + strlen(column->schema)
                   + 9 + strlen(column->table)
                   + 9 + strlen(column->orig_table)
                   + 9 + strlen(column->name)
@@ -912,7 +1142,7 @@
   ptr+= 4;
 
   ptr= drizzle_pack_string(column->catalog, ptr);
-  ptr= drizzle_pack_string(column->db, ptr);
+  ptr= drizzle_pack_string(column->schema, ptr);
   ptr= drizzle_pack_string(column->table, ptr);
   ptr= drizzle_pack_string(column->orig_table, ptr);
   ptr= drizzle_pack_string(column->name, ptr);

=== modified file 'libdrizzle-2.0/column.h'
--- libdrizzle-2.0/column.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/column.h	2011-11-18 02:03:41 +0000
@@ -82,9 +82,12 @@
 const char *drizzle_column_catalog(drizzle_column_st *column);
 
 /**
- * Get database name for a column.
+ * Get schema name for a column.
  */
 DRIZZLE_API
+const char *drizzle_column_shema(drizzle_column_st *column);
+
+DRIZZLE_API
 const char *drizzle_column_db(drizzle_column_st *column);
 
 /**

=== modified file 'libdrizzle-2.0/column_server.h'
--- libdrizzle-2.0/column_server.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/column_server.h	2011-11-18 02:03:41 +0000
@@ -71,6 +71,9 @@
  */
 DRIZZLE_API
 void drizzle_column_set_db(drizzle_column_st *column, const char *db);
+
+DRIZZLE_API
+void drizzle_column_set_schema(drizzle_column_st *column, const char *schema);
  
 /**
  * Set table name for a column.

=== modified file 'libdrizzle-2.0/command.cc'
--- libdrizzle-2.0/command.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/command.cc	2011-11-18 02:03:41 +0000
@@ -120,9 +120,13 @@
   con->buffer_size-= con->command_size;
 
   if (con->command_offset == con->command_total)
+  {
     drizzle_state_pop(con);
+  }
   else
+  {
     return DRIZZLE_RETURN_PAUSE;
+  }
 
   return DRIZZLE_RETURN_OK;
 }
@@ -159,7 +163,7 @@
                     + strlen(con->user) + 1
                     + 1  /* Scramble size */
                     + DRIZZLE_MAX_SCRAMBLE_SIZE
-                    + strlen(con->db) + 1;
+                    + strlen(con->schema) +1;
 
     /* Flush buffer if there is not enough room. */
     free_size= (size_t)DRIZZLE_MAX_BUFFER_SIZE - (size_t)(start - con->buffer);
@@ -174,9 +178,13 @@
     ptr= start;
     ptr[3]= 0;
     if (con->options & DRIZZLE_CON_MYSQL)
-      ptr[4]= (uint8_t)(con->command);
+    {
+      ptr[4]= uint8_t(con->command);
+    }
     else
-      ptr[4]= (uint8_t)(_command_drizzle_map[con->command]);
+    {
+      ptr[4]= uint8_t(_command_drizzle_map[con->command]);
+    }
     ptr+= 5;
 
     if (con->command == DRIZZLE_COMMAND_CHANGE_USER)

=== modified file 'libdrizzle-2.0/conn.cc'
--- libdrizzle-2.0/conn.cc	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/conn.cc	2011-11-18 02:03:41 +0000
@@ -267,7 +267,9 @@
   }
 
   if (password == NULL)
+  {
     con->password[0]= 0;
+  }
   else
   {
     strncpy(con->password, password, DRIZZLE_MAX_PASSWORD_SIZE);
@@ -275,93 +277,173 @@
   }
 }
 
+const char *drizzle_con_schema(const drizzle_con_st *con)
+{
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  return con->schema;
+}
+
 const char *drizzle_con_db(const drizzle_con_st *con)
 {
-  return con->db;
+  return drizzle_con_schema(con);
 }
 
-void drizzle_con_set_db(drizzle_con_st *con, const char *db)
+void drizzle_con_set_schema(drizzle_con_st *con, const char *schema)
 {
-  if (db == NULL)
-    con->db[0]= 0;
+  if (con == NULL)
+  {
+    return;
+  }
+
+  if (schema == NULL)
+  {
+    con->schema[0]= 0;
+  }
   else
   {
-    strncpy(con->db, db, DRIZZLE_MAX_DB_SIZE);
-    con->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+    strncpy(con->schema, schema, DRIZZLE_MAX_DB_SIZE);
+    con->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
   }
 }
 
+void drizzle_con_set_db(drizzle_con_st *con, const char *schema)
+{
+  drizzle_con_set_schema(con, schema);
+}
+
 void *drizzle_con_context(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   return con->context;
 }
 
 void drizzle_con_set_context(drizzle_con_st *con, void *context)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->context= context;
 }
 
 void drizzle_con_set_context_free_fn(drizzle_con_st *con,
                                      drizzle_con_context_free_fn *function)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->context_free_fn= function;
 }
 
 uint8_t drizzle_con_protocol_version(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->protocol_version;
 }
 
 const char *drizzle_con_server_version(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   return con->server_version;
 }
 
 uint32_t drizzle_con_server_version_number(const drizzle_con_st *con)
 {
-  uint32_t major;
-  uint32_t minor;
-  uint32_t version;
+  if (con == NULL)
+  {
+    return 0;
+  }
+
+  const char *current= con->server_version;
+
   char *end;
-
-  const char *current= con->server_version;
-
-  major= (uint32_t)strtoul(current, &end, 10);
-  current= end + 1;
-  minor= (uint32_t)strtoul(current, &end, 10);
-  current= end + 1;
-  version= (uint32_t)strtoul(current, &end, 10);
+  uint32_t major= (uint32_t)strtoul(current, &end, 10);
+  current= end + 1;
+
+  uint32_t minor= (uint32_t)strtoul(current, &end, 10);
+  current= end + 1;
+
+  uint32_t version= (uint32_t)strtoul(current, &end, 10);
 
   return (major * 10000) + (minor * 100) + version;
 }
 
 uint32_t drizzle_con_thread_id(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->thread_id;
 }
 
 const uint8_t *drizzle_con_scramble(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->scramble;
 }
 
 int drizzle_con_capabilities(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->capabilities;
 }
 
 drizzle_charset_t drizzle_con_charset(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return drizzle_charset_t();
+  }
+
   return con->charset;
 }
 
 drizzle_con_status_t drizzle_con_status(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return drizzle_con_status_t();
+  }
+
   return con->status;
 }
 
 uint32_t drizzle_con_max_packet_size(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->max_packet_size;
 }
 
@@ -371,8 +453,15 @@
 
 drizzle_return_t drizzle_con_connect(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (con->options & DRIZZLE_CON_READY)
+  {
     return DRIZZLE_RETURN_OK;
+  }
 
   if (drizzle_state_none(con))
   {
@@ -426,6 +515,11 @@
                                         drizzle_result_st *result,
                                         drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   if (con->options & DRIZZLE_CON_MYSQL)
   {
     return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_SHUTDOWN,
@@ -437,10 +531,9 @@
 }
 
 drizzle_result_st *drizzle_shutdown(drizzle_con_st *con,
-                                    drizzle_result_st *result, uint32_t level,
+                                    drizzle_result_st *result, uint32_t,
                                     drizzle_return_t *ret_ptr)
 {
-  (void) level;
   return drizzle_con_shutdown(con, result, ret_ptr);
 }
 
@@ -476,7 +569,10 @@
                                              size_t total,
                                              drizzle_return_t *ret_ptr)
 {
-  drizzle_result_st *old_result;
+  if (con == NULL)
+  {
+    return NULL;
+  }
 
   drizzle_return_t unused;
   if (ret_ptr == NULL)
@@ -484,12 +580,11 @@
     ret_ptr= &unused;
   }
 
-  if (!(con->options & DRIZZLE_CON_READY))
+  if ((con->options & DRIZZLE_CON_READY) == 0)
   {
     if (con->options & DRIZZLE_CON_RAW_PACKET)
     {
-      drizzle_set_error(con->drizzle, "drizzle_command_write",
-                        "connection not ready");
+      drizzle_set_error(con->drizzle, "drizzle_command_write", "connection not ready");
       *ret_ptr= DRIZZLE_RETURN_NOT_READY;
       return result;
     }
@@ -509,7 +604,7 @@
     }
     else
     {
-      for (old_result= con->result_list; old_result != NULL; old_result= old_result->next)
+      for (drizzle_result_st *old_result= con->result_list; old_result != NULL; old_result= old_result->next)
       {
         if (result == old_result)
         {
@@ -543,7 +638,9 @@
 
   *ret_ptr= drizzle_state_loop(con);
   if (*ret_ptr == DRIZZLE_RETURN_PAUSE)
+  {
     *ret_ptr= DRIZZLE_RETURN_OK;
+  }
   else if (*ret_ptr != DRIZZLE_RETURN_OK &&
            *ret_ptr != DRIZZLE_RETURN_IO_WAIT &&
            *ret_ptr != DRIZZLE_RETURN_ERROR_CODE)
@@ -561,8 +658,15 @@
 
 drizzle_return_t drizzle_con_listen(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (con->options & DRIZZLE_CON_READY)
+  {
     return DRIZZLE_RETURN_OK;
+  }
 
   if (drizzle_state_none(con))
   {
@@ -575,25 +679,47 @@
 
 int drizzle_con_backlog(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->backlog;
 }
 
 void drizzle_con_set_backlog(drizzle_con_st *con, int backlog)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->backlog= backlog;
 }
 
 void drizzle_con_set_protocol_version(drizzle_con_st *con,
                                       uint8_t protocol_version)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->protocol_version= protocol_version;
 }
 
 void drizzle_con_set_server_version(drizzle_con_st *con,
                                     const char *server_version)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   if (server_version == NULL)
+  {
     con->server_version[0]= 0;
+  }
   else
   {
     strncpy(con->server_version, server_version,
@@ -604,13 +730,25 @@
 
 void drizzle_con_set_thread_id(drizzle_con_st *con, uint32_t thread_id)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->thread_id= thread_id;
 }
 
 void drizzle_con_set_scramble(drizzle_con_st *con, const uint8_t *scramble)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   if (scramble == NULL)
+  {
     con->scramble= NULL;
+  }
   else
   {
     con->scramble= con->scramble_buffer;
@@ -621,30 +759,55 @@
 void drizzle_con_set_capabilities(drizzle_con_st *con,
                                   int capabilities)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->capabilities= capabilities;
 }
 
 void drizzle_con_set_charset(drizzle_con_st *con, drizzle_charset_t charset)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->charset= charset;
 }
 
 void drizzle_con_set_status(drizzle_con_st *con, drizzle_con_status_t status)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->status= status;
 }
 
 void drizzle_con_set_max_packet_size(drizzle_con_st *con,
                                      uint32_t max_packet_size)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->max_packet_size= max_packet_size;
 }
 
 void drizzle_con_copy_handshake(drizzle_con_st *con, drizzle_con_st *from)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   drizzle_con_set_auth(con, from->user, NULL);
   drizzle_con_set_scramble(con, from->scramble);
-  drizzle_con_set_db(con, from->db);
+  drizzle_con_set_db(con, from->schema);
   drizzle_con_set_protocol_version(con, from->protocol_version);
   drizzle_con_set_server_version(con, from->server_version);
   drizzle_con_set_thread_id(con, from->thread_id);
@@ -660,6 +823,17 @@
                                size_t *size, size_t *total,
                                drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (drizzle_state_none(con))
   {
     con->packet_number= 0;
@@ -690,11 +864,30 @@
   size_t offset= 0;
   size_t size= 0;
 
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  size_t total_unused;
+  if (total == NULL)
+  {
+    total= &total_unused;
+  }
+
   uint8_t *command_data=
     static_cast<uint8_t *>(drizzle_con_command_read(con, command, &offset,
                                                     &size, total, ret_ptr));
   if (*ret_ptr != DRIZZLE_RETURN_OK)
+  {
     return NULL;
+  }
 
   if (command_data == NULL)
   {
@@ -714,7 +907,9 @@
     command_data= (uint8_t *)drizzle_con_command_read(con, command, &offset,
                                                       &size, total, ret_ptr);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
+    }
 
     memcpy(con->command_buffer + offset, command_data, size);
   }
@@ -770,6 +965,11 @@
   struct addrinfo ai;
   int ret;
 
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_log_debug(con->drizzle, "drizzle_state_addrinfo");
 
   switch (con->socket_type)
@@ -784,11 +984,17 @@
     }
 
     if (tcp->port != 0)
+    {
       snprintf(port, NI_MAXSERV, "%u", tcp->port);
+    }
     else if (con->options & DRIZZLE_CON_MYSQL)
+    {
       snprintf(port, NI_MAXSERV, "%u", DRIZZLE_DEFAULT_TCP_PORT_MYSQL);
+    }
     else
+    {
       snprintf(port, NI_MAXSERV, "%u", DRIZZLE_DEFAULT_TCP_PORT);
+    }
     port[NI_MAXSERV-1]= 0;
 
     memset(&ai, 0, sizeof(ai));

=== modified file 'libdrizzle-2.0/conn.h'
--- libdrizzle-2.0/conn.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/conn.h	2011-11-18 02:03:41 +0000
@@ -290,6 +290,9 @@
  * @return Database associated with this connection.
  */
 DRIZZLE_API
+const char *drizzle_con_schema(const drizzle_con_st *con);
+
+DRIZZLE_API
 const char *drizzle_con_db(const drizzle_con_st *con);
 
 /**
@@ -297,10 +300,13 @@
  *
  * @param[in] con Connection structure previously initialized with
  *  drizzle_con_create(), drizzle_con_clone(), or related functions.
- * @param[in] db Database to use with this connection.
+ * @param[in] schema Database to use with this connection.
  */
 DRIZZLE_API
-void drizzle_con_set_db(drizzle_con_st *con, const char *db);
+void drizzle_con_set_schema(drizzle_con_st *con, const char *schema);
+
+DRIZZLE_API
+void drizzle_con_set_db(drizzle_con_st *con, const char *schema);
 
 /**
  * Get application context pointer for a connection.

=== modified file 'libdrizzle-2.0/constants.h'
--- libdrizzle-2.0/constants.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/constants.h	2011-11-18 02:03:41 +0000
@@ -69,7 +69,8 @@
 #define DRIZZLE_MAX_ERROR_SIZE           2048
 #define DRIZZLE_MAX_USER_SIZE            64
 #define DRIZZLE_MAX_PASSWORD_SIZE        32
-#define DRIZZLE_MAX_DB_SIZE              64
+#define DRIZZLE_MAX_SCHEMA_SIZE          64
+#define DRIZZLE_MAX_DB_SIZE              DRIZZLE_MAX_SCHEMA_SIZE
 #define DRIZZLE_MAX_INFO_SIZE            2048
 #define DRIZZLE_MAX_SQLSTATE_SIZE        5
 #define DRIZZLE_MAX_CATALOG_SIZE         128

=== modified file 'libdrizzle-2.0/drizzle.cc'
--- libdrizzle-2.0/drizzle.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/drizzle.cc	2011-11-18 02:03:41 +0000
@@ -326,7 +326,7 @@
   con->socket.tcp.host= NULL;
   con->socket.tcp.port= 0;
   /* con->buffer doesn't need to be set */
-  con->db[0]= 0;
+  con->schema[0]= 0;
   con->password[0]= 0;
   /* con->scramble_buffer doesn't need to be set */
   con->server_version[0]= 0;
@@ -348,7 +348,7 @@
                   DRIZZLE_CON_NO_RESULT_READ|DRIZZLE_CON_IO_READY|
                   DRIZZLE_CON_LISTEN));
   con->backlog= from->backlog;
-  strcpy(con->db, from->db);
+  strcpy(con->schema, from->schema);
   strcpy(con->password, from->password);
   strcpy(con->user, from->user);
 

=== modified file 'libdrizzle-2.0/handshake.cc'
--- libdrizzle-2.0/handshake.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/handshake.cc	2011-11-18 02:03:41 +0000
@@ -401,7 +401,9 @@
   con->buffer_ptr+= 1;
 
   if (scramble_size == 0)
+  {
     con->scramble= NULL;
+  }
   else
   {
     if (scramble_size != DRIZZLE_MAX_SCRAMBLE_SIZE)
@@ -418,9 +420,11 @@
     con->buffer_ptr+= DRIZZLE_MAX_SCRAMBLE_SIZE;
   }
 
-  /* Look for null-terminated db string. */
-  if ((34 + strlen(con->user) + scramble_size) == con->packet_size)
-    con->db[0]= 0;
+  /* Look for null-terminated schema string. */
+  if ((34 + strlen(con->user) +scramble_size) == con->packet_size)
+  {
+    con->schema[0]= 0;
+  }
   else
   {
     ptr= (uint8_t *)memchr(con->buffer_ptr, 0, con->buffer_size -
@@ -428,7 +432,7 @@
     if (ptr == NULL)
     {
       drizzle_set_error(con->drizzle, "drizzle_state_handshake_client_read",
-                        "db string not found");
+                        "schema string not found");
       return DRIZZLE_RETURN_BAD_HANDSHAKE_PACKET;
     }
 
@@ -442,13 +446,13 @@
 
     if (con->buffer_ptr == ptr)
     {
-      con->db[0]= 0;
+      con->schema[0]= 0;
       con->buffer_ptr++;
     }
     else
     {
-      strncpy(con->db, (char *)con->buffer_ptr, DRIZZLE_MAX_DB_SIZE);
-      con->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+      strncpy(con->schema, (char *)con->buffer_ptr, DRIZZLE_MAX_DB_SIZE);
+      con->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
       con->buffer_ptr+= ((ptr - con->buffer_ptr) + 1);
     }
   }
@@ -471,7 +475,6 @@
 {
   uint8_t *ptr;
   int capabilities;
-  drizzle_return_t ret;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_handshake_client_write");
 
@@ -483,7 +486,7 @@
                   + strlen(con->user) + 1
                   + 1   /* Scramble size */
                   + DRIZZLE_MAX_SCRAMBLE_SIZE
-                  + strlen(con->db) + 1;
+                  + strlen(con->schema) + 1;
 
   /* Assume the entire handshake packet will fit in the buffer. */
   if ((con->packet_size + 4) > DRIZZLE_MAX_BUFFER_SIZE)
@@ -501,7 +504,9 @@
   ptr+= 4;
 
   if (con->options & DRIZZLE_CON_MYSQL)
+  {
     con->capabilities|= DRIZZLE_CAPABILITIES_PROTOCOL_41;
+  }
 
   capabilities= con->capabilities & DRIZZLE_CAPABILITIES_CLIENT;
   if (!(con->options & DRIZZLE_CON_FOUND_ROWS))
@@ -523,8 +528,10 @@
   }
 
   capabilities&= ~(DRIZZLE_CAPABILITIES_COMPRESS | DRIZZLE_CAPABILITIES_SSL);
-  if (con->db[0] == 0)
+  if (con->schema[0] == 0)
+  {
     capabilities&= ~DRIZZLE_CAPABILITIES_CONNECT_WITH_DB;
+  }
 
   drizzle_set_byte4(ptr, capabilities);
   ptr+= 4;
@@ -538,9 +545,12 @@
   memset(ptr, 0, 23);
   ptr+= 23;
 
+  drizzle_return_t ret;
   ptr= drizzle_pack_auth(con, ptr, &ret);
   if (ret != DRIZZLE_RETURN_OK)
+  {
     return ret;
+  }
 
   con->buffer_size+= (4 + con->packet_size);
 
@@ -562,17 +572,18 @@
 
 drizzle_return_t drizzle_state_handshake_result_read(drizzle_con_st *con)
 {
-  drizzle_return_t ret;
   drizzle_result_st result;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_handshake_result_read");
 
   if (drizzle_result_create(con, &result) == NULL)
+  {
     return DRIZZLE_RETURN_MEMORY;
+  }
 
   con->result= &result;
 
-  ret= drizzle_state_result_read(con);
+  drizzle_return_t ret= drizzle_state_result_read(con);
   if (drizzle_state_none(con))
   {
     if (ret == DRIZZLE_RETURN_OK)
@@ -591,7 +602,9 @@
   drizzle_result_free(&result);
 
   if (ret == DRIZZLE_RETURN_ERROR_CODE)
+  {
     return DRIZZLE_RETURN_HANDSHAKE_FAILED;
+  }
 
   return ret;
 }

=== modified file 'libdrizzle-2.0/libdrizzle.hpp'
--- libdrizzle-2.0/libdrizzle.hpp	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/libdrizzle.hpp	2011-11-18 02:03:41 +0000
@@ -247,7 +247,7 @@
   query_c& p_name(const std::string& v)
   {
     std::vector<char> r(2 * v.size() + 2);
-    r.resize(drizzle_escape_string(&r.front() + 1, v.data(), v.size()) + 2);    
+    r.resize(drizzle_escape_string(&r.front() + 1, r.size(), v.data(), v.size()) + 2);    
     r.front() = '`';
     r.back() = '`';
     p_raw(&r.front(), r.size());
@@ -274,7 +274,7 @@
   query_c& p(const std::string& v)
   {
     std::vector<char> r(2 * v.size() + 2);
-    r.resize(drizzle_escape_string(&r.front() + 1, v.data(), v.size()) + 2);    
+    r.resize(drizzle_escape_string(&r.front() + 1, r.size(), v.data(), v.size()) + 2);    
     r.front() = '\'';
     r.back() = '\'';
     p_raw(&r.front(), r.size());

=== modified file 'libdrizzle-2.0/pack.cc'
--- libdrizzle-2.0/pack.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/pack.cc	2011-11-18 02:03:41 +0000
@@ -145,6 +145,11 @@
 
 uint8_t *drizzle_pack_string(char *string, uint8_t *ptr)
 {
+  if (string == NULL)
+  {
+    return NULL;
+  }
+
   uint64_t size= strlen(string);
 
   ptr= drizzle_pack_length(size, ptr);
@@ -163,6 +168,11 @@
   drizzle_return_t ret= DRIZZLE_RETURN_OK;
   uint64_t length;
 
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   length= drizzle_unpack_length(con, &ret);
   if (ret != DRIZZLE_RETURN_OK)
   {
@@ -178,7 +188,9 @@
   if (length < max_length)
   {
     if (length > 0)
+    {
       memcpy(buffer, con->buffer_ptr, (size_t)length);
+    }
 
     buffer[length]= 0;
   }
@@ -195,9 +207,19 @@
   return DRIZZLE_RETURN_OK;
 }
 
-uint8_t *drizzle_pack_auth(drizzle_con_st *con, uint8_t *ptr,
-                           drizzle_return_t *ret_ptr)
+uint8_t *drizzle_pack_auth(drizzle_con_st *con, uint8_t *ptr, drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (con->user[0] != 0)
   {
     memcpy(ptr, con->user, strlen(con->user));
@@ -235,7 +257,9 @@
     {
       *ret_ptr= _pack_scramble_hash(con, ptr);
       if (*ret_ptr != DRIZZLE_RETURN_OK)
+      {
         return ptr;
+      }
     }
     else // We assume Drizzle
     {
@@ -246,16 +270,17 @@
     ptr+= DRIZZLE_MAX_SCRAMBLE_SIZE;
   }
 
-  if (con->db[0] != 0)
+  if (con->schema[0] != 0)
   {
-    memcpy(ptr, con->db, strlen(con->db));
-    ptr+= strlen(con->db);
+    memcpy(ptr, con->schema, strlen(con->schema));
+    ptr+= strlen(con->schema);
   }
 
   ptr[0]= 0;
   ptr++;
 
   *ret_ptr= DRIZZLE_RETURN_OK;
+
   return ptr;
 }
 
@@ -266,7 +291,6 @@
 static drizzle_return_t _pack_scramble_hash(drizzle_con_st *con,
                                             uint8_t *buffer)
 {
-  uint32_t x;
   SHA1_CTX ctx;
   uint8_t hash_tmp1[SHA1_DIGEST_LENGTH];
   uint8_t hash_tmp2[SHA1_DIGEST_LENGTH];
@@ -303,8 +327,10 @@
   SHA1Final(buffer, &ctx);
 
   /* Fourth, xor the last hash against the first password hash. */
-  for (x= 0; x < SHA1_DIGEST_LENGTH; x++)
+  for (uint32_t x= 0; x < SHA1_DIGEST_LENGTH; x++)
+  {
     buffer[x]= buffer[x] ^ hash_tmp1[x];
+  }
 
   return DRIZZLE_RETURN_OK;
 }

=== modified file 'libdrizzle-2.0/query.cc'
--- libdrizzle-2.0/query.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/query.cc	2011-11-18 02:03:41 +0000
@@ -351,7 +351,7 @@
   return DRIZZLE_RETURN_OK;
 }
 
-ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size)
+ssize_t drizzle_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size)
 {
   ssize_t to_size= 0;
   char newchar;
@@ -393,7 +393,9 @@
     if (newchar != '\0')
     {
       if ((size_t)to_size + 2 > max_to_size)
+      {
         return -1;
+      }
 
       *to++= '\\';
       *to++= newchar;
@@ -402,7 +404,9 @@
     else
     {
       if ((size_t)to_size + 1 > max_to_size)
+      {
         return -1;
+      }
 
       *to++= *from;
     }
@@ -414,11 +418,6 @@
   return to_size;
 }
 
-size_t drizzle_escape_string(char *to, const char *from, size_t from_size)
-{
-  return (size_t) drizzle_safe_escape_string(to, (from_size * 2), from, from_size);
-}
-
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size)
 {
   static const char hex_map[]= "0123456789ABCDEF";

=== modified file 'libdrizzle-2.0/query.h'
--- libdrizzle-2.0/query.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/query.h	2011-11-18 02:03:41 +0000
@@ -227,11 +227,11 @@
  * size of the output string in to.
  */
 DRIZZLE_API
-size_t drizzle_escape_string(char *to, const char *from, size_t from_size);
-DRIZZLE_API
-ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size);
+ssize_t drizzle_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size);
+
 DRIZZLE_API
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size);
+
 DRIZZLE_API
 void drizzle_mysql_password_hash(char *to, const char *from, size_t from_size);
 

=== modified file 'libdrizzle-2.0/structs.h'
--- libdrizzle-2.0/structs.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/structs.h	2011-11-18 02:03:41 +0000
@@ -181,7 +181,7 @@
     drizzle_con_uds_st uds;
   } socket;
   uint8_t buffer[DRIZZLE_MAX_BUFFER_SIZE];
-  char db[DRIZZLE_MAX_DB_SIZE];
+  char schema[DRIZZLE_MAX_DB_SIZE];
   char password[DRIZZLE_MAX_PASSWORD_SIZE];
   uint8_t scramble_buffer[DRIZZLE_MAX_SCRAMBLE_SIZE];
   char server_version[DRIZZLE_MAX_SERVER_VERSION_SIZE];
@@ -333,7 +333,7 @@
   drizzle_column_st *prev;
   int options;
   char catalog[DRIZZLE_MAX_CATALOG_SIZE];
-  char db[DRIZZLE_MAX_DB_SIZE];
+  char schema[DRIZZLE_MAX_DB_SIZE];
   char table[DRIZZLE_MAX_TABLE_SIZE];
   char orig_table[DRIZZLE_MAX_TABLE_SIZE];
   char name[DRIZZLE_MAX_COLUMN_NAME_SIZE];

=== modified file 'unittests/libdrizzle_test.cc'
--- unittests/libdrizzle_test.cc	2011-11-04 21:06:16 +0000
+++ unittests/libdrizzle_test.cc	2011-11-18 02:03:41 +0000
@@ -31,9 +31,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_escape_string(out, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(17, out_len);
   BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
@@ -43,9 +42,8 @@
 {
   const char orig[6]= {0x00, 0x01, 0x02, 0x03, 0x04, 0x05};
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_escape_string(out, orig, 6);
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, 6);
 
   BOOST_REQUIRE_EQUAL(7, out_len);
   BOOST_REQUIRE_EQUAL("\\0\1\2\3\4\5", out);
@@ -55,9 +53,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[255];
-  ssize_t out_len;
 
-  out_len= drizzle_safe_escape_string(out, 255, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(17, out_len);
   BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
@@ -67,9 +64,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[5];
-  ssize_t out_len;
 
-  out_len= drizzle_safe_escape_string(out, 5, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(-1, out_len);
 }
@@ -78,9 +74,8 @@
 {
   const unsigned char orig[5]= {0x34, 0x26, 0x80, 0x99, 0xFF};
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_hex_string(out, (char*) orig, 5);
+  size_t out_len= drizzle_hex_string(out, (char*) orig, 5);
 
   BOOST_REQUIRE_EQUAL(10, out_len);
   BOOST_REQUIRE_EQUAL("34268099FF", out);

